extract_map_entry_raw

Function extract_map_entry_raw 

pub fn extract_map_entry_raw(blob: &[u8], key: &str) -> Option<Vec<u8>>
Extract a map entry as raw bytes without decoding the entire map.

This is useful for extracting a single property from overflow JSON without paying the cost of decoding all other properties.

Returns None if:

  • The blob is not a TAG_MAP
  • The key doesn’t exist in the map
  • Deserialization fails