pub struct LockPoisonedError {
pub lock_name: &'static str,
}Expand description
Error returned when a lock is poisoned.
A lock becomes poisoned when a thread panics while holding the lock. This error type allows callers to decide how to handle poisoned locks.
Fields
lock_name: &'static strDescription of which lock was poisoned.