#[non_exhaustive]pub enum UniError {
Show 33 variants
NotFound {
path: PathBuf,
},
Schema {
message: String,
},
Parse {
message: String,
position: Option<usize>,
line: Option<usize>,
column: Option<usize>,
context: Option<String>,
},
Query {
message: String,
query: Option<String>,
},
Transaction {
message: String,
},
TransactionConflict {
message: String,
},
TransactionAlreadyCompleted,
ReadOnly {
operation: String,
},
LabelNotFound {
label: String,
},
EdgeTypeNotFound {
edge_type: String,
},
PropertyNotFound {
property: String,
entity_type: String,
label: String,
},
IndexNotFound {
index: String,
},
SnapshotNotFound {
snapshot_id: String,
},
MemoryLimitExceeded {
limit_bytes: usize,
},
DatabaseLocked,
Timeout {
timeout_ms: u64,
},
Type {
expected: String,
actual: String,
},
Constraint {
message: String,
},
Storage {
message: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
Io(Error),
Internal(Error),
InvalidIdentifier {
name: String,
reason: String,
},
LabelAlreadyExists {
label: String,
},
EdgeTypeAlreadyExists {
edge_type: String,
},
PermissionDenied {
action: String,
},
InvalidArgument {
arg: String,
message: String,
},
WriteContextAlreadyActive {
session_id: String,
hint: &'static str,
},
CommitTimeout {
tx_id: String,
hint: &'static str,
},
TransactionExpired {
tx_id: String,
hint: &'static str,
},
Cancelled,
StaleDerivedFacts {
version_gap: u64,
},
RuleConflict {
rule_name: String,
},
HookRejected {
message: String,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
Schema
Parse
Fields
Query
Transaction
TransactionConflict
TransactionAlreadyCompleted
ReadOnly
Operation not supported on read-only database
LabelNotFound
Label not found in schema
EdgeTypeNotFound
Edge type not found in schema
PropertyNotFound
Property not found on node/edge
IndexNotFound
Index not found
SnapshotNotFound
Snapshot not found
MemoryLimitExceeded
Query memory limit exceeded
DatabaseLocked
Timeout
Type
Constraint
Storage
Io(Error)
Internal(Error)
InvalidIdentifier
LabelAlreadyExists
EdgeTypeAlreadyExists
PermissionDenied
InvalidArgument
WriteContextAlreadyActive
Write context (transaction, bulk writer, or appender) is already active on session.
CommitTimeout
Transaction commit timed out waiting for the global writer lock.
TransactionExpired
Transaction exceeded its deadline.
Cancelled
Operation was cancelled via a cancellation token.
StaleDerivedFacts
Derived facts are stale relative to the current database version.
RuleConflict
A Locy rule conflict was detected during transaction commit rule promotion.
HookRejected
A session hook rejected the operation.