#[non_exhaustive]pub enum DistanceMetric {
Cosine,
L2,
Dot,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl DistanceMetric
impl DistanceMetric
Sourcepub fn compute_distance(&self, a: &[f32], b: &[f32]) -> f32
pub fn compute_distance(&self, a: &[f32], b: &[f32]) -> f32
Computes the distance between two vectors using this metric.
All metrics follow LanceDB conventions so that lower values indicate greater similarity:
- L2: squared Euclidean distance.
- Cosine:
1.0 - cosine_similarity(range [0, 2]). - Dot: negative dot product.
Panics
Panics if a and b have different lengths.